@@ -22,14 +22,14 @@ def _get_kwargs(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/msg/".format(client.base_url, app_id=app_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -104,7 +104,7 @@ def sync_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageOut:
     """List Messages
 
@@ -124,7 +124,7 @@ def sync_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageOut
@@ -171,7 +171,7 @@ def sync(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageOut:
     """List Messages
 
@@ -191,7 +191,7 @@ def sync(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageOut
@@ -220,7 +220,7 @@ async def asyncio_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageOut:
     """List Messages
 
@@ -240,7 +240,7 @@ async def asyncio_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageOut
@@ -285,7 +285,7 @@ async def asyncio(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageOut:
     """List Messages
 
@@ -305,7 +305,7 @@ async def asyncio(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageOut
