@@ -27,7 +27,7 @@ def _get_kwargs(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/attempt/endpoint/{endpoint_id}/".format(
         client.base_url, app_id=app_id, endpoint_id=endpoint_id
@@ -36,7 +36,7 @@ def _get_kwargs(
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -126,7 +126,7 @@ def sync_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Endpoint
 
@@ -154,7 +154,7 @@ def sync_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -207,7 +207,7 @@ def sync(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Endpoint
 
@@ -235,7 +235,7 @@ def sync(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -270,7 +270,7 @@ async def asyncio_detailed(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Endpoint
 
@@ -298,7 +298,7 @@ async def asyncio_detailed(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -349,7 +349,7 @@ async def asyncio(
     channel: Union[Unset, None, str] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts By Endpoint
 
@@ -377,7 +377,7 @@ async def asyncio(
         channel (Union[Unset, None, str]):  Example: project_1337.
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
