@@ -18,14 +18,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/stats/app/{app_id}/attempt/".format(client.base_url, app_id=app_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -81,7 +81,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get App Attempt Stats
 
@@ -91,7 +91,7 @@ def sync_detailed(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -130,7 +130,7 @@ def sync(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get App Attempt Stats
 
@@ -140,7 +140,7 @@ def sync(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -161,7 +161,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get App Attempt Stats
 
@@ -171,7 +171,7 @@ async def asyncio_detailed(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
@@ -208,7 +208,7 @@ async def asyncio(
     client: AuthenticatedClient,
     start_date: Union[Unset, None, datetime.datetime] = UNSET,
     end_date: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> AttemptStatisticsResponse:
     """Get App Attempt Stats
 
@@ -218,7 +218,7 @@ async def asyncio(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         start_date (Union[Unset, None, datetime.datetime]):
         end_date (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         AttemptStatisticsResponse
